"""
web2ldap plugin classes for attributes defined in SCHAC

See http://www.terena.org/activities/tf-emc2/schac.html

$Id: schac.py,v 1.5 2009/03/19 16:12:07 michael Exp $
"""

import re
from w2lapp.schema.syntaxes import NumericString,CountryString,DNSDomain,syntax_registry
from w2lapp.schema.plugins.msperson import Gender


syntax_registry.registerAttrType(
  CountryString.oid,[
    '1.3.6.1.4.1.25178.1.2.5',  # schacCountryOfCitizenship 
    '1.3.6.1.4.1.25178.1.2.11', # schacCountryOfResidence
  ]
)

syntax_registry.registerAttrType(
  DNSDomain.oid,[
    '1.3.6.1.4.1.25178.1.2.9', # schacHomeOrganization
  ]
)

class SchacMotherTongue(NumericString):
  oid = 'SchacMotherTongue-oid'
  desc = 'Language tag of the language a person learns first (see RFC 3066).'
  reObj = re.compile('^[a-zA-Z]{2,8}(-[a-zA-Z0-9]{2,8})*$')

syntax_registry.registerAttrType(
  SchacMotherTongue.oid,[
    '1.3.6.1.4.1.25178.1.2.1', # schacMotherTongue
  ]
)


syntax_registry.registerAttrType(
  Gender.oid,[
    '1.3.6.1.4.1.25178.1.2.2', # schacGender
  ]
)


class SchacDateOfBirth(NumericString):
  oid = 'SchacDateOfBirth-oid'
  desc = 'Date of birth: syntax YYYYMMDD'
  maxLen = 10
  reObj = re.compile('^[0-9]{4}[0-1][0-9][0-3][0-9]$')

syntax_registry.registerAttrType(
  SchacDateOfBirth.oid,[
    '1.3.6.1.4.1.25178.1.2.3', # schacDateOfBirth
  ]
)


class SchacYearOfBirth(NumericString):
  oid = 'SchacYearOfBirth-oid'
  desc = 'Year of birth: syntax YYYY'
  maxLen = 4
  reObj = re.compile('^[0-9]{4}$')

syntax_registry.registerAttrType(
  SchacYearOfBirth.oid,[
    '1.3.6.1.4.1.25178.1.0.3', # schacYearOfBirth
  ]
)


# Register all syntax classes in this module
for symbol_name in dir():
  syntax_registry.registerSyntaxClass(eval(symbol_name))
